@@ -21,7 +21,7 @@
 #' \item placing a single node elsewhere in the order
 #' \item staying still
 #' }
-#' @param iterations integer, the number of MCMC steps, the default value is \eqn{5n^{2}\log{n}}
+#' @param iterations integer, the number of MCMC steps, the default value is \eqn{6n^{2}\log{n}}
 #' @param stepsave integer, thinning interval for the MCMC chain, indicating the number of steps between two output iterations, the default is \code{iterations/1000}
 #' @param alpha numerical significance value in \code{\{0,1\}} for the conditional independence tests at the PC algorithm stage (by default \eqn{0.4} for \eqn{n<50}, \eqn{20/n} for \eqn{n>50})
 #' @param gamma tuning parameter which transforms the score by raising it to this power, 1 by default
@@ -31,11 +31,11 @@
 #' @param verbose logical, if TRUE messages about the algorithm's progress will be printed, FALSE by default
 #' @param startspace (optional) a square matrix, of dimensions equal to the number of nodes, which defines the search space for the order MCMC in the form of an adjacency matrix. If NULL, the skeleton obtained from the PC-algorithm will be used. If \code{startspace[i,j]} equals to 1 (0) it means that the edge from node \code{i} to node \code{j} is included (excluded) from the search space. To include an edge in both directions, both \code{startspace[i,j]} and \code{startspace[j,i]} should be 1.
 #' @param blacklist (optional) a square matrix, of dimensions equal to the number of nodes, which defines edges to exclude from the search space. If \code{blacklist[i,j]} equals to 1 it means that the edge from node \code{i} to node \code{j} is excluded from the search space.
-#' @param scoretable (optional) object of class \code{MCMCspace} containing list of score tables calculated for example by the last iteration of the function \code{iterativeMCMC}. When not NULL, parameter \code{startspace} is ignored.
+#' @param scoretable (optional) object of class \code{scorespace} containing list of score tables calculated for example by the last iteration of the function \code{iterativeMCMC}. When not NULL, parameter \code{startspace} is ignored.
 #' @param startorder (optional) integer vector of length n, which will be used as the starting order in the MCMC algorithm, the default order is random
-#' @return Object of class \code{MCMCres}, which contains log-score trace of sampled DAGs as well 
-#' as adjacency matrix of the maximum scoring DAG, its score and the order score. See \code{\link{MCMCres}}.
-#' The output can optionally include DAGs sampled in MCMC iterations and the score tables. Optional output is regulated by the parameters \code{chainout} and \code{scoreout}.
+#' @return Object of class \code{orderMCMC}, which contains log-score trace of sampled DAGs as well 
+#' as adjacency matrix of the maximum scoring DAG, its score and the order score. The output can optionally include DAGs sampled in MCMC iterations and the score tables. 
+#' Optional output is regulated by the parameters \code{chainout} and \code{scoreout}. See \code{\link{orderMCMC class}} for a detailed class structure.
 #'@references Friedman N and Koller D (2003). A Bayesian approach to structure discovery in bayesian networks. Machine Learning 50, 95-125.
 #'@references Kalisch M, Maechler M, Colombo D, Maathuis M and Buehlmann P (2012). Causal inference using graphical models with the R package pcalg. Journal of Statistical Software 47, 1-26.
 #'@references Geiger D and Heckerman D (2002). Parameter priors for directed acyclic graphical models and the characterization of several probability distributions. The Annals of Statistics 30, 1412-1440.
@@ -54,7 +54,6 @@
 #'}
 #'@author Polina Suter, Jack Kuipers, the code partly derived from the order MCMC implementation from Kuipers J, Moffa G (2017) <doi:10.1080/01621459.2015.1133426>
 #'@export
-
 orderMCMC<-function(scorepar, MAP=TRUE, plus1=TRUE,chainout=FALSE, scoreout=FALSE, moveprobs=NULL, 
                     iterations=NULL, stepsave=NULL, alpha=0.05, cpdag=FALSE, gamma=1,
                     hardlimit=ifelse(plus1,14,20),verbose=FALSE,
@@ -71,7 +70,7 @@ orderMCMC<-function(scorepar, MAP=TRUE, plus1=TRUE,chainout=FALSE, scoreout=FALS
     if(scorepar$nsmall<26){
       iterations<-30000
     } else {
-      iterations<-(5*scorepar$nsmall*scorepar$nsmall*log(scorepar$nsmall))-(5*scorepar$nsmall*scorepar$nsmall*log(scorepar$nsmall)) %% 1000
+      iterations<-(6*scorepar$nsmall*scorepar$nsmall*log(scorepar$nsmall))-(6*scorepar$nsmall*scorepar$nsmall*log(scorepar$nsmall)) %% 1000
     }
   }
   if(is.null(stepsave)){
@@ -159,7 +158,9 @@ orderMCMC<-function(scorepar, MAP=TRUE, plus1=TRUE,chainout=FALSE, scoreout=FALS
     result$info$sampletype<-"sample"
   }
   
-  attr(result,"class")<-"MCMCres"
+  result$info$fncall<-match.call()
+  
+  attr(result,"class")<-"orderMCMC"
   
   return(result)
   
@@ -179,17 +180,18 @@ orderMCMC<-function(scorepar, MAP=TRUE, plus1=TRUE,chainout=FALSE, scoreout=FALS
 #' \item move a single node into another partition element or into a new one
 #' \item stay still
 #' }
-#' @param iterations integer, the number of MCMC steps, the default value is \eqn{8n^{2}\log{n}}
+#' @param iterations integer, the number of MCMC steps, the default value is \eqn{20n^{2}\log{n}}
 #' @param stepsave integer, thinning interval for the MCMC chain, indicating the number of steps between two output iterations, the default is \code{iterations/1000}
 #' @param gamma tuning parameter which transforms the score by raising it to this power, 1 by default
 #' @param verbose logical, if set to TRUE (default) messages about progress will be printed
 #' @param scoreout logical, if TRUE the search space and score tables are returned, FALSE by default
 #' @param startspace (optional) a square matrix, of dimensions equal to the number of nodes, which defines the search space for the order MCMC in the form of an adjacency matrix; if NULL, the skeleton obtained from the PC-algorithm will be used. If \code{startspace[i,j]} equals to 1 (0) it means that the edge from node \code{i} to node \code{j} is included (excluded) from the search space. To include an edge in both directions, both \code{startspace[i,j]} and \code{startspace[j,i]} should be 1.
 #' @param blacklist (optional) a square matrix, of dimensions equal to the number of nodes, which defines edges to exclude from the search space; if \code{blacklist[i,j]=1} it means that the edge from node \code{i} to node \code{j} is excluded from the search space
-#' @param scoretable (optional) object of class \code{MCMCspace} containing list of score tables calculated for example by the last iteration of the function \code{iterativeMCMC}. When not NULL, parameter \code{startspace} is ignored
+#' @param scoretable (optional) object of class \code{scorespace} containing list of score tables calculated for example by the last iteration of the function \code{iterativeMCMC}. When not NULL, parameter \code{startspace} is ignored
 #' @param startDAG (optional) an adjacency matrix of dimensions equal to the number of nodes, representing a DAG in the search space defined by startspace.  If startspace is defined but \code{startDAG} is not, an empty DAG will be used by default
-#' @return Object of class \code{MCMCres}, which contains log-score trace as well 
-#' as adjacency matrix of the maximum scoring DAG, its score and the order score. See \code{\link{MCMCres}}.
+#' @return Object of class \code{partitionMCMC}, which contains log-score trace as well 
+#' as adjacency matrix of the maximum scoring DAG, its score and the order score. Additionally, returns all sampled DAGs (represented by their adjacency matrices), their scores,
+#'orders and partitions See \code{\link{partitionMCMC class}}.
 #'@references Kuipers J and Moffa G (2017). Partition MCMC for inference on acyclic digraphs. Journal of the American Statistical Association 112, 282-299.
 #'@references Geiger D and Heckerman D (2002). Parameter priors for directed acyclic graphical models and the characterization of several probability distributions. The Annals of Statistics 30, 1412-1440.
 #'@references Heckerman D and Geiger D (1995). Learning Bayesian networks: A unification for discrete and Gaussian domains. In Eleventh Conference on Uncertainty in Artificial Intelligence, pages 274-284.
@@ -204,7 +206,7 @@ orderMCMC<-function(scorepar, MAP=TRUE, plus1=TRUE,chainout=FALSE, scoreout=FALS
 #'@import pcalg
 #'@author Polina Suter, Jack Kuipers, the code partly derived from the partition MCMC implementation from Kuipers J, Moffa G (2017) <doi:10.1080/01621459.2015.1133426>
 #'@export
-partitionMCMC<-function(scorepar, moveprobs=NULL, iterations=NULL,  stepsave=NULL,gamma=1,verbose=TRUE,
+partitionMCMC<-function(scorepar, moveprobs=NULL, iterations=NULL,  stepsave=NULL,gamma=1,verbose=FALSE,
                         scoreout=FALSE,startspace=NULL, blacklist=NULL,scoretable=NULL, startDAG=NULL) {
   if (is.null(moveprobs)) {
     prob1start<-40/100
@@ -219,27 +221,16 @@ partitionMCMC<-function(scorepar, moveprobs=NULL, iterations=NULL,  stepsave=NUL
     moveprobs<-moveprobs.partition/sum(moveprobs.partition) # normalisation
   } 
   if(is.null(iterations)){
-    if(scorepar$nsmall<26){
-      iterations<-30000
+    if(scorepar$nsmall<20){
+      iterations<-20000
     } else {
-      iterations<-(8*scorepar$nsmall*scorepar$nsmall*log(scorepar$nsmall))-(8*scorepar$nsmall*scorepar$nsmall*log(scorepar$nsmall)) %% 1000
+      iterations<-(20*scorepar$nsmall*scorepar$nsmall*log(scorepar$nsmall))-(20*scorepar$nsmall*scorepar$nsmall*log(scorepar$nsmall)) %% 1000
     }
   }
   if(is.null(stepsave)){
     stepsave<-floor(iterations/1000)
   }
   
-  #no startorder needed for partitionMCMC
-  # ordercheck<-checkstartorder(startorder,varnames=scorepar$labels.short,mainnodes=scorepar$mainnodes,
-  #                             bgnodes=scorepar$static,DBN=scorepar$DBN,split=scorepar$split)
-  # 
-  # if(ordercheck$errorflag) {
-  #   stop(ordercheck$message)
-  # } else {
-  #   startorder<-ordercheck$order
-  # }
-  # 
-  
   if(scorepar$DBN) { #flag for DBN structure learning with different initial and transition structures
     
     if(!is.null(blacklist)) {
@@ -305,7 +296,9 @@ partitionMCMC<-function(scorepar, moveprobs=NULL, iterations=NULL,  stepsave=NUL
   result$info$iterations<-iterations
   result$info$samplesteps<-length(result$trace)
   result$info$sampletype<-"sample"
-  attr(result,"class")<-"MCMCres"
+  result$info$fncall<-match.call()
+  
+  attr(result,"class")<-"partitionMCMC"
   return(result)
 }
 
@@ -313,7 +306,7 @@ partitionMCMC<-function(scorepar, moveprobs=NULL, iterations=NULL,  stepsave=NUL
 #'Structure learning with an iterative order MCMC algorithm on an expanded search space
 #'
 #'This function implements an iterative search for the maximum a posteriori (MAP) DAG, 
-#'by means of order MCMC.  At each iteration, the current search space is expanded by 
+#'by means of order MCMC (arXiv:1803.07859v3).  At each iteration, the current search space is expanded by 
 #'allowing each node to have up to one additional parent not already included in the search space. 
 #'By default the initial search space is obtained through the PC-algorithm (using the functions \code{\link[pcalg]{skeleton}} and \code{\link[pcalg]{pc}} from the `pcalg' package [Kalisch et al, 2012]).  
 #'At each iteration order MCMC is employed to search for the MAP DAG.  
@@ -349,7 +342,7 @@ partitionMCMC<-function(scorepar, moveprobs=NULL, iterations=NULL,  stepsave=NUL
 #' @param accum logical, when TRUE at each search step expansion new edges are added to the current search space; when FALSE (default) the new edges are added to the starting space
 #' @param plus1it (optional) integer, a number of iterations of search space expansion; by default the algorithm iterates until no score improvement can be achieved by further expanding the search space
 #' @param startspace (optional) a square matrix, of dimensions equal to the number of nodes, which defines the search space for the order MCMC in the form of an adjacency matrix; if NULL, the skeleton obtained from the PC-algorithm will be used; if \code{startspace[i,j]} equals to 1 (0) it means that the edge from node \code{i} to node \code{j} is included (excluded) from the search space; to include an edge in both directions, both \code{startspace[i,j]} and \code{startspace[j,i]} should be 1
-#' @param scoretable (optional) object of class \code{MCMCscoretab} (see \code{\link{MCMCscoretab}}). When not NULL, parameters \code{startspace} and \code{addspace} are ignored.
+#' @param scoretable (optional) object of class \code{scorespace}. When not NULL, parameters \code{startspace} and \code{addspace} are ignored.
 #' @param addspace (optional) a square matrix, of dimensions equal to the number of nodes, which defines the edges, which are added at to the search space only at the first iteration of iterative seach and do not necessarily stay afterwards; defined in the form of an adjacency matrix;  if \code{addspace[i,j]} equals to 1 (0) it means that the edge from node \code{i} to node \code{j} is included (excluded) from the search space; to include an edge in both directions, both \code{addspace[i,j]} and \code{addspace[j,i]} should be 1
 #' @param blacklist (optional) a square matrix, of dimensions equal to the number of nodes, which defines edges to exclude from the search space; if \code{blacklist[i,j]} equals to 1 it means that the edge from node \code{i} to node \code{j} is excluded from the search space
 #' \itemize{
@@ -360,9 +353,9 @@ partitionMCMC<-function(scorepar, moveprobs=NULL, iterations=NULL,  stepsave=NUL
 #' @param verbose logical, if TRUE (default) prints messages on the progress of execution
 #' @param chainout logical, if TRUE the saved MCMC steps are returned, FALSE by default
 #' @param scoreout logical, if TRUE the search space from the last plus1 iterations and the corresponding score tables are returned, FALSE by default
-#' @return Object of class \code{MCMCmult}, which contains log-score trace as well 
-#' as adjacency matrix of the maximum scoring DAG, its score and the order score. See \code{\link{MCMCmult}}.
-#' The output can optionally include DAGs sampled in MCMC iterations and the score tables. Optional output is regulated by the parameters \code{chainout} and \code{scoreout}.
+#' @return Object of class \code{iterativeMCMC}, which contains log-score trace as well as adjacency matrix of the maximum scoring DAG, its score and the order score. 
+#' The output can optionally include DAGs sampled in MCMC iterations and the score tables. Optional output is regulated by the parameters \code{chainout} and \code{scoreout}. See \code{\link{iterativeMCMC class}} for a detailed class structure.
+#'@references Kuipers J, Super P and Moffa G (2020). Efficient Sampling and Structure Learning of Bayesian Networks. (arXiv:1803.07859v3)
 #'@references Friedman N and Koller D (2003). A Bayesian approach to structure discovery in bayesian networks. Machine Learning 50, 95-125.
 #'@references Kalisch M, Maechler M, Colombo D, Maathuis M and Buehlmann P (2012). Causal inference using graphical models with the R package pcalg. Journal of Statistical Software 47, 1-26.
 #'@references Geiger D and Heckerman D (2002). Parameter priors for directed acyclic graphical models and the characterization of several probability distributions. The Annals of Statistics 30, 1412-1440.
@@ -396,12 +389,14 @@ partitionMCMC<-function(scorepar, moveprobs=NULL, iterations=NULL,  stepsave=NUL
 #'@importFrom graph graph.par
 #'@importFrom graph plot
 #'@importFrom graph numNodes
+#'@importFrom graphics text
 #'@importFrom Rcpp evalCpp
 #'@importFrom graphics abline
 #'@importFrom utils head
 #'@useDynLib BiDAG, .registration=TRUE
-#'@export
-#'@author Polina Suter, Jack Kuipers, the code partly derived from the order MCMC implementation from Kuipers J, Moffa G (2017) <doi:10.1080/01621459.2015.1133426>
+#'@rdname iterativeMCMC
+#'@export iterativeMCMC
+#'@author Polina Suter, Jack Kuipers
 iterativeMCMC<-function(scorepar, MAP=TRUE, posterior=0.5, softlimit=9, hardlimit=12, alpha=0.05, gamma=1, verbose=TRUE, chainout=FALSE, scoreout=FALSE, cpdag=FALSE, 
                         mergetype="skeleton", iterations=NULL, moveprobs=NULL, stepsave=NULL,startorder=NULL,
                         accum=FALSE, plus1it=NULL, startspace=NULL, blacklist=NULL,addspace=NULL,scoretable=NULL) {
@@ -496,7 +491,7 @@ iterativeMCMC<-function(scorepar, MAP=TRUE, posterior=0.5, softlimit=9, hardlimi
     result$info$split<-scorepar$split
     
   }
-  result$info$algo<-"iterative plus1 order MCMC"
+  result$info$algo<-"iterative order MCMC"
   if(is.null(startspace)) {
     result$info$spacealgo<-"PC"
   } else {
@@ -512,7 +507,8 @@ iterativeMCMC<-function(scorepar, MAP=TRUE, posterior=0.5, softlimit=9, hardlimi
     result$info$threshold<-posterior
   }
   
-  attr(result,"class")<-"MCMCmult"
+  result$info$fncall<-match.call()
+  attr(result,"class")<-"iterativeMCMC"
   
   return(result)
   
@@ -572,12 +568,11 @@ DAGscore <- function(scorepar, incidence){
 #' \code{incidence[i,j]} equals 0 otherwise
 #' @return the log of the BGe or BDe score of the DBN
 #' @examples
-#' testscore<-scoreparameters("bge", DBNdata, bgnodes=c(1,2,3), DBN=TRUE,
-#'                         dbnpar=list(slices=5, stationary=TRUE))
+#' testscore<-scoreparameters("bge", DBNdata, DBN=TRUE, dbnpar=list(slices=5, b=3))
 #' DBNscore(testscore, DBNmat)
 #'
 #' @export
-#' @author Polina Suter, Jack Kuipers, the code partly derived from the order MCMC implementation from Kuipers J, Moffa G (2017) <doi:10.1080/01621459.2015.1133426>
+#' @author Polina Suter, Jack Kuipers
 DBNscore<-function(scorepar,incidence) {
   
   if(nrow(incidence)==ncol(incidence) & ncol(incidence)==(2*scorepar$nsmall+scorepar$bgn)) {
